@@ -7,12 +7,13 @@ use v5.10.1;
 use strict;
 use warnings;
 
+use base 'Exporter::Tiny';
+
 use Cache::FastMmap;
 use Class::Method::Modifiers qw/ install_modifier /;
-use Exporter qw/ import /;
 use Object::Signature ();
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.3.0';
 
 our @EXPORT    = qw/ cache /;
 our @EXPORT_OK = @EXPORT;
@@ -59,7 +60,7 @@ Class::Method::Cache::FastMmap - Cache method results using Cache::FastMmap
 
 =head1 VERSION
 
-version v0.2.0
+version v0.3.0
 
 =head1 SYNOPSIS
 
@@ -101,6 +102,8 @@ The C<%options> are as follows:
 is used to specify a different (shared) cache. You may use another
 caching class, so long as it provides C<get> and C<set> methods.
 
+Added v0.2.0.
+
 =item C<key_cb>
 
 is used to provide a custom key-generation function.  If
@@ -111,17 +114,34 @@ corresponding to the original method call parameters:
 
   $key_cb->( [ $self, @_ ] );
 
-Remaining C<%options> are passed to the constructor for
-L<Cache::FastMmap>.
-
 =item C<prefix>
 
 This is the prefix too prepend to the key. It defaults to the class
 and method name when the L</cache> is specified, or an empty string
 otherwise.
 
+Added v0.2.0.
+
 =back
 
+Remaining C<%options> are passed to the constructor for
+L<Cache::FastMmap>.
+
+As of v0.3.0, you can import the C<cache> method with a different
+namme:
+
+  use Class::Method::Cache::FastMmap
+     "cache" => { -as => "memoize" };
+
+  sub my_method {
+    ...
+  }
+
+  memoize 'my_method' => (
+     serializer  => 'storable',
+     expire_time => '1h',
+  );
+
 =head1 SEE ALSO
 
 L<Cache::FastMmap>
